(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/forms'), require('@angular/cdk/keycodes'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('ngx-payment-inputs', ['exports', '@angular/core', '@angular/common', '@angular/forms', '@angular/cdk/keycodes', 'rxjs', 'rxjs/operators'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-payment-inputs'] = {}, global.ng.core, global.ng.common, global.ng.forms, global.ng.cdk.keycodes, global.rxjs, global.rxjs.operators));
}(this, (function (exports, core, common, forms, keycodes, rxjs, operators) { 'use strict';

    /**
     * @description returns a value without spaces
     * @param value {string} - any string
     */
    function clearSpaces (value) {
        if (!value) {
            return;
        }
        return String(value).replace(/\s/g, '');
    }

    var DEFAULT_CVC_LENGTH = 3;
    var DEFAULT_ZIP_LENGTH = 5;
    var DEFAULT_CARD_FORMAT = /(\d{1,4})/g;
    /**
     * Card Types per BIN
     * @internal
     */
    var CARD_TYPES = [
        {
            displayName: 'Visa',
            type: 'visa',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^4/,
            gaps: [4, 8, 12],
            lengths: [16, 18, 19],
            code: {
                name: 'CVV',
                length: 3,
            },
        },
        {
            displayName: 'Mastercard',
            type: 'mastercard',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(5[1-5]|677189)|^(222[1-9]|2[3-6]\d{2}|27[0-1]\d|2720)/,
            gaps: [4, 8, 12],
            lengths: [16],
            code: {
                name: 'CVC',
                length: 3,
            },
        },
        {
            displayName: 'American Express',
            type: 'amex',
            format: /(\d{1,4})(\d{1,6})?(\d{1,5})?/,
            startPattern: /^3[47]/,
            gaps: [4, 10],
            lengths: [15],
            code: {
                name: 'CID',
                length: 4,
            },
        },
        {
            displayName: 'Diners Club',
            type: 'dinersclub',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(36|38|30[0-5])/,
            gaps: [4, 10],
            lengths: [14, 16, 19],
            code: {
                name: 'CVV',
                length: 3,
            },
        },
        {
            displayName: 'Discover',
            type: 'discover',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(6011|65|64[4-9]|622)/,
            gaps: [4, 8, 12],
            lengths: [16, 19],
            code: {
                name: 'CID',
                length: 3,
            },
        },
        {
            displayName: 'JCB',
            type: 'jcb',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^35/,
            gaps: [4, 8, 12],
            lengths: [16, 17, 18, 19],
            code: {
                name: 'CVV',
                length: 3,
            },
        },
        {
            displayName: 'UnionPay',
            type: 'unionpay',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^62/,
            gaps: [4, 8, 12],
            lengths: [14, 15, 16, 17, 18, 19],
            code: {
                name: 'CVN',
                length: 3,
            },
        },
        {
            displayName: 'Maestro',
            type: 'maestro',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(5018|5020|5038|6304|6703|6708|6759|676[1-3])/,
            gaps: [4, 8, 12],
            lengths: [12, 13, 14, 15, 16, 17, 18, 19],
            code: {
                name: 'CVC',
                length: 3,
            },
        },
        {
            displayName: 'Elo',
            type: 'elo',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(4011(78|79)|43(1274|8935)|45(1416|7393|763(1|2))|50(4175|6699|67[0-7][0-9]|9000)|627780|63(6297|6368)|650(03([^4])|04([0-9])|05(0|1)|4(0[5-9]|3[0-9]|8[5-9]|9[0-9])|5([0-2][0-9]|3[0-8])|9([2-6][0-9]|7[0-8])|541|700|720|901)|651652|655000|655021)/,
            gaps: [4, 8, 12],
            lengths: [16],
            code: {
                name: 'CVE',
                length: 3,
            },
        },
        {
            displayName: 'Hipercard',
            type: 'hipercard',
            format: DEFAULT_CARD_FORMAT,
            startPattern: /^(384100|384140|384160|606282|637095|637568|60(?!11))/,
            gaps: [4, 8, 12],
            lengths: [16],
            code: {
                name: 'CVC',
                length: 3,
            },
        },
    ];
    /**
     * Get card type by card value
     * @param value - card number value
     * @returns object with all properties from card type
     */
    var getCardTypeByValue = function (value) { return CARD_TYPES.filter(function (cardType) { return cardType.startPattern.test(value); })[0]; };
    /**
     * Get card type by type (ie.: visa, elo, hipercard)
     * @param value - card type (ie.: visa, elo, hipercard, amex)
     * @returns object with all properties from card type
     */
    var getCardTypeByType = function (type) { return CARD_TYPES.filter(function (cardType) { return cardType.type === type; })[0]; };

    var cardTypes = /*#__PURE__*/Object.freeze({
        __proto__: null,
        DEFAULT_CVC_LENGTH: DEFAULT_CVC_LENGTH,
        DEFAULT_ZIP_LENGTH: DEFAULT_ZIP_LENGTH,
        DEFAULT_CARD_FORMAT: DEFAULT_CARD_FORMAT,
        CARD_TYPES: CARD_TYPES,
        getCardTypeByValue: getCardTypeByValue,
        getCardTypeByType: getCardTypeByType
    });

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from) {
        for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
            to[j] = from[i];
        return to;
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, privateMap) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to get private field on non-instance");
        }
        return privateMap.get(receiver);
    }
    function __classPrivateFieldSet(receiver, privateMap, value) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to set private field on non-instance");
        }
        privateMap.set(receiver, value);
        return value;
    }

    /**
     * @description format card number based on card type list per card BIN
     * @param cardNumber {string} - card number form html input
     */
    var formatCardNumber = function (cardNumber) {
        var _a, _b;
        var cardType = getCardTypeByValue(cardNumber);
        if (!cardType)
            return (_a = ((cardNumber === null || cardNumber === void 0 ? void 0 : cardNumber.match(/\d+/g)) || [])) === null || _a === void 0 ? void 0 : _a.join('');
        var format = cardType === null || cardType === void 0 ? void 0 : cardType.format;
        if (format === null || format === void 0 ? void 0 : format.global) {
            return (_b = ((cardNumber === null || cardNumber === void 0 ? void 0 : cardNumber.match(format)) || [])) === null || _b === void 0 ? void 0 : _b.join(' ');
        }
        if (format) {
            var execResult = format.exec(cardNumber.split(' ').join(''));
            if (execResult) {
                return execResult
                    .splice(1, 3)
                    .filter(function (x) { return x; })
                    .join(' ');
            }
        }
        return cardNumber;
    };
    /**
     * @description Format expiry date based on card BIN
     * @param event {unknown} - Event from card date expiry date
     * @returns string
     */
    var formatExpiry = function (event) {
        var _a, _b, _c, _d;
        var eventData = (_a = event === null || event === void 0 ? void 0 : event.nativeEvent) === null || _a === void 0 ? void 0 : _a.data;
        var prevExpiry = (_d = (_c = (_b = event === null || event === void 0 ? void 0 : event.target) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.split(' / ')) === null || _d === void 0 ? void 0 : _d.join('/');
        if (!prevExpiry)
            return null;
        var expiry = prevExpiry;
        if (/^[2-9]$/.test(expiry)) {
            expiry = "0" + expiry;
        }
        if (prevExpiry.length === 2 && +prevExpiry > 12) {
            var _e = __read(prevExpiry.split('')), head = _e[0], tail = _e.slice(1);
            expiry = "0" + head + "/" + tail.join('');
        }
        if (/^1[/-]$/.test(expiry)) {
            return "01 / ";
        }
        expiry = expiry.match(/(\d{1,2})/g) || [];
        if ((expiry === null || expiry === void 0 ? void 0 : expiry.length) === 1) {
            if (!eventData && prevExpiry.includes('/')) {
                return expiry[0];
            }
            if (/\d{2}/.test(expiry)) {
                return expiry[0] + " / ";
            }
        }
        if ((expiry === null || expiry === void 0 ? void 0 : expiry.length) > 2) {
            var _f = __read(expiry.join('').match(/^(\d{2}).*(\d{2})$/) || [], 3), _g = _f[1], month = _g === void 0 ? null : _g, _h = _f[2], year = _h === void 0 ? null : _h;
            return [month, year].join(' / ');
        }
        return expiry.join(' / ');
    };

    var formatters = /*#__PURE__*/Object.freeze({
        __proto__: null,
        formatCardNumber: formatCardNumber,
        formatExpiry: formatExpiry
    });

    var MONTH_REGEX = /(0[1-9]|1[0-2])/;
    var EMPTY_CARD_NUMBER = 'Enter a card number';
    var EMPTY_EXPIRY_DATE = 'Enter an expiry date';
    var EMPTY_CVC = 'Enter a CVC';
    var EMPTY_ZIP = 'Enter a ZIP code';
    var INVALID_CARD_NUMBER = 'Card number is invalid';
    var INVALID_EXPIRY_DATE = 'Expiry date is invalid';
    var INVALID_CVC = 'CVC is invalid';
    var MONTH_OUT_OF_RANGE = 'Expiry month must be between 01 and 12';
    var YEAR_OUT_OF_RANGE = 'Expiry year cannot be in the past';
    var DATE_OUT_OF_RANGE = 'Expiry date cannot be in the past';
    /**
     * Check if a input value has reached max value based on card BIN
     * @param currentValue - current card number value without spaces
     * @returns if card number has reached max lenght
     */
    var hasCardNumberReachedMaxLength = function (currentValue) {
        var cardType = cardTypes === null || cardTypes === void 0 ? void 0 : getCardTypeByValue(currentValue);
        return cardType && cardType.lengths.some(function (l) { return clearSpaces(currentValue).length === l; });
    };
    /**
     * check if value is a numeric type
     * @param e {KeyboardEvent} - Event from input
     * @returns if a value is a numeric value
     */
    var isNumeric = function (e) {
        var _a;
        return (_a = /^\d*$/) === null || _a === void 0 ? void 0 : _a.test(e === null || e === void 0 ? void 0 : e.key);
    };
    /**
     * Validate card number luhn
     * @param cardNumber - card number without spaces
     */
    var validateLuhn = function (cardNumber) {
        return (cardNumber
            .split('')
            .reverse()
            .map(function (digit) { return parseInt(digit, 10); })
            .map(function (digit, idx) { return (idx % 2 ? digit * 2 : digit); })
            .map(function (digit) { return (digit > 9 ? (digit % 10) + 1 : digit); })
            .reduce(function (accum, digit) { return (accum += digit); }) %
            10 ===
            0);
    };
    /**
     * Get all error messages from card number
     * @param cardNumber - card number without spaces
     * @param cardNumberValidator - fn to validate a card number
     * @param errorMessageObject - object with all error messages
     * @returns returns error message for card number
     */
    var getCardNumberError = function (cardNumber, cardNumberValidator, _b) {
        var _c = (_b === void 0 ? {} : _b).errorMessages, errorMessages = _c === void 0 ? {} : _c;
        if (!cardNumber) {
            return errorMessages.emptyCardNumber || EMPTY_CARD_NUMBER;
        }
        var rawCardNumber = cardNumber.replace(/\s/g, '');
        var cardType = getCardTypeByValue(rawCardNumber);
        if (cardType && cardType.lengths) {
            var doesCardNumberMatchLength = cardType.lengths.includes(rawCardNumber.length);
            if (doesCardNumberMatchLength) {
                var isLuhnValid = validateLuhn(rawCardNumber);
                if (isLuhnValid) {
                    if (cardNumberValidator) {
                        return cardNumberValidator({ cardNumber: rawCardNumber, cardType: cardType, errorMessages: errorMessages });
                    }
                    return;
                }
            }
        }
        return errorMessages.invalidCardNumber || INVALID_CARD_NUMBER;
    };
    /**
     * get all error messages from card expire date
     * @param expiryDate - expire date
     * @param expiryValidator - fn to validade a card expire date
     * @param errorMessageObject - object with all error message
     * @returns error message for date validation
     */
    var getExpiryDateError = function (expiryDate, expiryValidator, _b) {
        var _c = (_b === void 0 ? {} : _b).errorMessages, errorMessages = _c === void 0 ? {} : _c;
        if (!expiryDate) {
            return errorMessages.emptyExpiryDate || EMPTY_EXPIRY_DATE;
        }
        var rawExpiryDate = expiryDate.replace(' / ', '').replace('/', '');
        if (rawExpiryDate.length === 4) {
            var month = rawExpiryDate.slice(0, 2);
            var year = "20" + rawExpiryDate.slice(2, 4);
            if (!MONTH_REGEX.test(month)) {
                return errorMessages.monthOutOfRange || MONTH_OUT_OF_RANGE;
            }
            if (parseInt(year) < new Date().getFullYear()) {
                return errorMessages.yearOutOfRange || YEAR_OUT_OF_RANGE;
            }
            if (parseInt(year) === new Date().getFullYear() &&
                parseInt(month) < new Date().getMonth() + 1) {
                return errorMessages.dateOutOfRange || DATE_OUT_OF_RANGE;
            }
            if (expiryValidator) {
                return expiryValidator({ expiryDate: { month: month, year: year }, errorMessages: errorMessages });
            }
            return;
        }
        return errorMessages.invalidExpiryDate || INVALID_EXPIRY_DATE;
    };
    /**
     * get all error messages from card cvc
     * @param cvc - cvc number
     * @param cvcValidator - validator fn for cvc
     * @param errorMessageObject - object with all error message
     * @returns error message for  cvc
     */
    var getCVCError = function (cvc, cvcValidator, _b) {
        var _c = _b === void 0 ? {} : _b, cardType = _c.cardType, _d = _c.errorMessages, errorMessages = _d === void 0 ? {} : _d;
        if (!cvc) {
            return errorMessages.emptyCVC || EMPTY_CVC;
        }
        if (cvc.length < 3) {
            return errorMessages.invalidCVC || INVALID_CVC;
        }
        if (cardType && cvc.length !== cardType.code.length) {
            return errorMessages.invalidCVC || INVALID_CVC;
        }
        if (cvcValidator) {
            return cvcValidator({ cvc: cvc, cardType: cardType, errorMessages: errorMessages });
        }
        return;
    };
    /**
     * get all error messages from card cvc
     * @param zip - zip code
     * @param errorMessageObject - object with all error message
     * @returns error message for zip code
     */
    var getZIPError = function (zip, _b) {
        var _c = (_b === void 0 ? {} : _b).errorMessages, errorMessages = _c === void 0 ? {} : _c;
        if (!zip) {
            return errorMessages.emptyZIP || EMPTY_ZIP;
        }
        return;
    };

    var validators = /*#__PURE__*/Object.freeze({
        __proto__: null,
        EMPTY_CARD_NUMBER: EMPTY_CARD_NUMBER,
        EMPTY_EXPIRY_DATE: EMPTY_EXPIRY_DATE,
        EMPTY_CVC: EMPTY_CVC,
        EMPTY_ZIP: EMPTY_ZIP,
        INVALID_CARD_NUMBER: INVALID_CARD_NUMBER,
        INVALID_EXPIRY_DATE: INVALID_EXPIRY_DATE,
        INVALID_CVC: INVALID_CVC,
        MONTH_OUT_OF_RANGE: MONTH_OUT_OF_RANGE,
        YEAR_OUT_OF_RANGE: YEAR_OUT_OF_RANGE,
        DATE_OUT_OF_RANGE: DATE_OUT_OF_RANGE,
        hasCardNumberReachedMaxLength: hasCardNumberReachedMaxLength,
        isNumeric: isNumeric,
        validateLuhn: validateLuhn,
        getCardNumberError: getCardNumberError,
        getExpiryDateError: getExpiryDateError,
        getCVCError: getCVCError,
        getZIPError: getZIPError
    });

    // kEYCODES FOR BACKSPACE KEY
    var BACKSPACE_KEY_CODE = 'backspace';
    var BACKSPACE_KEY_NUMBER = keycodes.BACKSPACE;
    // kEYCODES FOR ENTER KEY
    var ENTER_KEY_CODE = 'enter';
    var ENTER_KEY_NUMBER = keycodes.ENTER;
    /**
     * Timeout seconds to update element value
     * @internal
     */
    var TIMEOUT_SECONDS = 0;
    /**
     * check if a value is valid
     * @param value - value to check if has value
     */
    function isValue(value) {
        return !(value == null || value === '' || value !== value);
    }
    var utils = {
        cardTypes: cardTypes,
        formatters: formatters,
        validators: validators,
        isValue: isValue,
        BACKSPACE_KEY_CODE: BACKSPACE_KEY_CODE,
        BACKSPACE_KEY_NUMBER: BACKSPACE_KEY_NUMBER,
        ENTER_KEY_CODE: ENTER_KEY_CODE,
        ENTER_KEY_NUMBER: ENTER_KEY_NUMBER,
    };

    var CardTypeService = /** @class */ (function () {
        function CardTypeService() {
            this._cardType$ = new rxjs.BehaviorSubject(undefined);
        }
        Object.defineProperty(CardTypeService.prototype, "cardType", {
            /**
             * Getter for card type observable
             */
            get: function () {
                return this._cardType$.asObservable();
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardTypeService.prototype, "cardNumberRef", {
            /**
             * Getter for card number input ref
             */
            get: function () {
                return this._cardNumberRef;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardTypeService.prototype, "cardExpiryRef", {
            /**
             * Getter for card expiry date input ref
             */
            get: function () {
                return this._cardExpiryRef;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardTypeService.prototype, "cardCVVRef", {
            /**
             * Getter for card CVC input ref
             */
            get: function () {
                return this._cardCVVRef;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Update card type object with card type from card input field.
         * @param type - card type object
         */
        CardTypeService.prototype.setCardType = function (type) {
            this._cardType$.next(type);
        };
        /**
         * update value of element ref for the Card Number
         * @param el - ElementRef of the Card Number
         * @template E - Type of HTML Element
         */
        CardTypeService.prototype.setCardNumberRef = function (el) {
            this._cardNumberRef = el;
        };
        /**
         * update value of element ref for the Date Expire Input
         * @param el - ElementRef of the Card Expire
         * @template E - Type of HTML Element
         */
        CardTypeService.prototype.setCardExpireRef = function (el) {
            this._cardExpiryRef = el;
        };
        /**
         * update value of element ref for the CVV Input
         * @param el - ElementRef of the Card CVV
         * @template E - Type of HTML Element
         */
        CardTypeService.prototype.setCardCVVRef = function (el) {
            this._cardCVVRef = el;
        };
        return CardTypeService;
    }());
    CardTypeService.decorators = [
        { type: core.Injectable }
    ];
    CardTypeService.ctorParameters = function () { return []; };

    /**
     * Directive to format and validate a card number input type
     */
    var CardNumberDirective = /** @class */ (function () {
        function CardNumberDirective(_renderer, _elementRef, _ngControl, _cardTypeService) {
            this._renderer = _renderer;
            this._elementRef = _elementRef;
            this._ngControl = _ngControl;
            this._cardTypeService = _cardTypeService;
            this.onChange = function () { };
            this.onTouched = function () { };
        }
        CardNumberDirective.prototype.ngOnInit = function () {
            this._setupInput();
            this._cardTypeService.setCardNumberRef(this._elementRef);
        };
        CardNumberDirective.prototype.ngOnDestroy = function () {
            if (this._rendererTimeout) {
                window === null || window === void 0 ? void 0 : window.clearTimeout(this._rendererTimeout);
            }
        };
        Object.defineProperty(CardNumberDirective.prototype, "_el", {
            /**
             * get the current html input from element ref
             * @returns The native element from ref
             * @private
             */
            get: function () {
                return this._elementRef.nativeElement;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardNumberDirective.prototype, "_control", {
            /**
             * get the control of the current element ref
             * @returns return the control of element
             * @private
             */
            get: function () {
                return this._ngControl.control;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * listener the input event from html input element
         * @param event - the keyboard event
         */
        CardNumberDirective.prototype.onCardChanges = function (event) {
            this.writeValue(event);
        };
        /**
         * listener the input blur event to update input mask
         * @param event - the keyboard event
         */
        CardNumberDirective.prototype.onCardBlur = function (event) {
            this.writeValue(event);
        };
        /**
         * Writes a new value to the element.
         * @param rawValue - value from input
         */
        CardNumberDirective.prototype.writeValue = function (rawValue) {
            var _this = this;
            var _a;
            var cardNumber = ((_a = rawValue === null || rawValue === void 0 ? void 0 : rawValue.target) === null || _a === void 0 ? void 0 : _a.value) || '';
            var cardNumberFormatted = clearSpaces(cardNumber);
            var cardValue = utils.formatters.formatCardNumber(cardNumberFormatted);
            var cardType = utils.cardTypes.getCardTypeByValue(cardNumberFormatted);
            var cardNumberError = utils.validators.getCardNumberError(cardValue, null);
            // update card type value
            this._cardTypeService.setCardType(cardType);
            // check errors
            if (!cardNumberError) {
                this._checkCardNumberMaxLength(rawValue);
                this._control.setValidators(null);
            }
            // update ng control value
            this._rendererTimeout = window === null || window === void 0 ? void 0 : window.setTimeout(function () {
                _this._ngControl.viewToModelUpdate(cardValue);
                _this._ngControl.valueAccessor.writeValue(cardValue);
            }, TIMEOUT_SECONDS);
        };
        /**
         * Registers a callback function that is called when the control's value changes in the UI.
         * @param onChange - {fn}
         */
        CardNumberDirective.prototype.registerOnChange = function (onChange) {
            this.onChange = onChange;
        };
        /**
         * Registers a callback function that is called by the forms API on initialization to update the form model on blur.
         * @param onTouched - {fn}
         */
        CardNumberDirective.prototype.registerOnTouched = function (onTouched) {
            this.onTouched = onTouched;
        };
        /**
         * set element ref as disabled
         * @param isDisabled - set element as disabled
         */
        CardNumberDirective.prototype.setDisabledState = function (isDisabled) {
            this._renderer.setProperty(this._el, 'disabled', isDisabled);
            this._control.disable({ onlySelf: true });
            this._ngControl.valueAccessor.setDisabledState(isDisabled);
        };
        /**
         * Check if card number has reached max value and focus into expire date field
         * @param event {KeyboardEvent} - Keyboard event from the card number input
         */
        CardNumberDirective.prototype._checkCardNumberMaxLength = function (event) {
            var _a, _b, _c;
            var cardNumber = ((_a = event === null || event === void 0 ? void 0 : event.target) === null || _a === void 0 ? void 0 : _a.value) || '';
            var cardNumberFormatted = clearSpaces(cardNumber);
            var hasReachedMaxLength = utils.validators.hasCardNumberReachedMaxLength(cardNumberFormatted);
            if (hasReachedMaxLength) {
                event.preventDefault();
                (_c = (_b = this._cardTypeService.cardExpiryRef) === null || _b === void 0 ? void 0 : _b.nativeElement) === null || _c === void 0 ? void 0 : _c.focus();
            }
        };
        /**
         * setup input with some attrs for better user experience
         */
        CardNumberDirective.prototype._setupInput = function () {
            this._renderer.setProperty(this._el, 'autoComplete', 'cc-number');
            this._renderer.setProperty(this._el, 'aria-label', 'Card Number');
            this._renderer.setProperty(this._el, 'id', 'ccCardNumber');
            this._renderer.setProperty(this._el, 'name', 'ccCardNumber');
            this._renderer.setProperty(this._el, 'type', 'tel');
        };
        return CardNumberDirective;
    }());
    CardNumberDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'input[jstCardNumber][formControlName],input[formControl][jstCardNumber]',
                    host: {
                        '(blur)': 'onTouched()',
                    },
                },] }
    ];
    CardNumberDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef },
        { type: forms.NgControl, decorators: [{ type: core.Optional }] },
        { type: CardTypeService }
    ]; };
    CardNumberDirective.propDecorators = {
        onCardChanges: [{ type: core.HostListener, args: ['input', ['$event'],] }],
        onCardBlur: [{ type: core.HostListener, args: ['blur', ['$event'],] }]
    };

    /**
     * Directive to format and validate a card expiry date
     */
    var CardExpireDateDirective = /** @class */ (function () {
        function CardExpireDateDirective(_renderer, _elementRef, _ngControl, _cardTypeService) {
            this._renderer = _renderer;
            this._elementRef = _elementRef;
            this._ngControl = _ngControl;
            this._cardTypeService = _cardTypeService;
            this.onChange = function () { };
            this.onTouched = function () { };
        }
        CardExpireDateDirective.prototype.ngOnInit = function () {
            this._setupInput();
            this._cardTypeService.setCardExpireRef(this._elementRef);
        };
        CardExpireDateDirective.prototype.ngOnDestroy = function () {
            if (this._rendererTimeout) {
                window === null || window === void 0 ? void 0 : window.clearTimeout(this._rendererTimeout);
            }
        };
        Object.defineProperty(CardExpireDateDirective.prototype, "_el", {
            /**
             * get the current html input from element ref
             * @returns The native element from ref
             * @private
             */
            get: function () {
                return this._elementRef.nativeElement;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardExpireDateDirective.prototype, "_control", {
            /**
             * get the control of the current element ref
             * @returns return the control of element
             * @private
             */
            get: function () {
                return this._ngControl.control;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * listener the input event from html input element
         * @param event - the keyboard event
         */
        CardExpireDateDirective.prototype.onCardChanges = function (event) {
            this.writeValue(event);
        };
        /**
         * listener the input blur event to update input mask
         * @param event - the keyboard event
         */
        CardExpireDateDirective.prototype.onCardBlur = function (event) {
            this.writeValue(event);
        };
        /**
         * Listener the keydown to check when backspace is pressed
         * @param event {KeyboardEvent} - The keyboard event
         */
        CardExpireDateDirective.prototype.onKeyDown = function (event) {
            var _a, _b, _c, _d;
            var value = (_a = event === null || event === void 0 ? void 0 : event.target) === null || _a === void 0 ? void 0 : _a.value;
            if (event.key.toLowerCase() === utils.BACKSPACE_KEY_CODE && !utils.isValue(value)) {
                // focus into card number field case expiry date has empty
                (_d = (_c = (_b = this._cardTypeService) === null || _b === void 0 ? void 0 : _b.cardNumberRef) === null || _c === void 0 ? void 0 : _c.nativeElement) === null || _d === void 0 ? void 0 : _d.focus();
            }
        };
        /**
         * Writes a new value to the element.
         * @param rawValue - value from input
         */
        CardExpireDateDirective.prototype.writeValue = function (rawValue) {
            var _this = this;
            var expireValue = utils.formatters.formatExpiry(rawValue);
            this._rendererTimeout = window === null || window === void 0 ? void 0 : window.setTimeout(function () {
                _this._ngControl.viewToModelUpdate(expireValue);
                _this._ngControl.valueAccessor.writeValue(expireValue);
            }, TIMEOUT_SECONDS);
        };
        /**
         * Registers a callback function that is called when the control's value changes in the UI.
         * @param onChange - {fn}
         */
        CardExpireDateDirective.prototype.registerOnChange = function (onChange) {
            this.onChange = onChange;
        };
        /**
         * Registers a callback function that is called by the forms API on initialization to update the form model on blur.
         * @param onTouched - {fn}
         */
        CardExpireDateDirective.prototype.registerOnTouched = function (onTouched) {
            this.onTouched = onTouched;
        };
        /**
         * set element ref as disabled
         * @param isDisabled - set element as disabled
         */
        CardExpireDateDirective.prototype.setDisabledState = function (isDisabled) {
            this._renderer.setProperty(this._el, 'disabled', isDisabled);
            this._control.disable({ onlySelf: true });
            this._ngControl.valueAccessor.setDisabledState(isDisabled);
        };
        /**
         * setup input with some attrs for better user experience
         */
        CardExpireDateDirective.prototype._setupInput = function () {
            this._renderer.setProperty(this._el, 'autoComplete', 'cc-exp');
            this._renderer.setProperty(this._el, 'aria-label', 'Expiry date in format MM YY');
            this._renderer.setProperty(this._el, 'id', 'ccExpireDate');
            this._renderer.setProperty(this._el, 'name', 'ccExpireDate');
            this._renderer.setProperty(this._el, 'type', 'tel');
        };
        return CardExpireDateDirective;
    }());
    CardExpireDateDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'input[jstCardExpireDate][formControlName],input[formControl][jstCardExpireDate]',
                    host: {
                        '(blur)': 'onTouched()',
                    },
                },] }
    ];
    CardExpireDateDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef },
        { type: forms.NgControl, decorators: [{ type: core.Optional }] },
        { type: CardTypeService }
    ]; };
    CardExpireDateDirective.propDecorators = {
        onCardChanges: [{ type: core.HostListener, args: ['input', ['$event'],] }],
        onCardBlur: [{ type: core.HostListener, args: ['blur', ['$event'],] }],
        onKeyDown: [{ type: core.HostListener, args: ['keydown', ['$event'],] }]
    };

    /**
     * Directive to format and validate a card CVC
     */
    var CardCvvDirective = /** @class */ (function () {
        function CardCvvDirective(_renderer, _elementRef, _ngControl, _cardTypeService) {
            this._renderer = _renderer;
            this._elementRef = _elementRef;
            this._ngControl = _ngControl;
            this._cardTypeService = _cardTypeService;
            this.onChange = function () { };
            this.onTouched = function () { };
            /**
             * attr for stop all subscribes
             */
            this._destroy$ = new rxjs.Subject();
        }
        CardCvvDirective.prototype.ngOnInit = function () {
            this._setupInput();
            this._cardTypeService.setCardCVVRef(this._elementRef);
        };
        CardCvvDirective.prototype.ngAfterViewInit = function () {
            this._setCardCvcMask();
        };
        CardCvvDirective.prototype.ngOnDestroy = function () {
            this._destroy$.next();
            this._destroy$.complete();
            if (this._rendererTimeout) {
                window === null || window === void 0 ? void 0 : window.clearTimeout(this._rendererTimeout);
            }
        };
        Object.defineProperty(CardCvvDirective.prototype, "_el", {
            /**
             * get the current html input from element ref
             * @returns The native element from ref
             * @private
             */
            get: function () {
                return this._elementRef.nativeElement;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(CardCvvDirective.prototype, "_control", {
            /**
             * get the control of the current element ref
             * @returns return the control of element
             * @private
             */
            get: function () {
                return this._ngControl.control;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * listener the input event from html input element
         * @param event - the keyboard event
         */
        CardCvvDirective.prototype.onCardChanges = function (event) {
            this.writeValue(event);
        };
        /**
         * listener the input blur event to update input mask
         * @param event - the keyboard event
         */
        CardCvvDirective.prototype.onCardBlur = function (event) {
            this.writeValue(event);
        };
        /**
         * Listener the keydown to check when backspace is pressed
         * @param event {KeyboardEvent} - The keyboard event
         */
        CardCvvDirective.prototype.onKeyDown = function (event) {
            var _a, _b, _c, _d;
            var value = (_a = event === null || event === void 0 ? void 0 : event.target) === null || _a === void 0 ? void 0 : _a.value;
            if (event.key.toLowerCase() === utils.BACKSPACE_KEY_CODE && !utils.isValue(value)) {
                // focus into card number field case expiry date is empty
                (_d = (_c = (_b = this._cardTypeService) === null || _b === void 0 ? void 0 : _b.cardExpiryRef) === null || _c === void 0 ? void 0 : _c.nativeElement) === null || _d === void 0 ? void 0 : _d.focus();
            }
        };
        /**
         * Writes a new value to the element.
         * @param rawValue - value from input
         */
        CardCvvDirective.prototype.writeValue = function (rawValue) {
            var _this = this;
            var _a;
            var cvcValue = ((_a = rawValue.target) === null || _a === void 0 ? void 0 : _a.value) || '';
            var cvcValueFormatted = clearSpaces(cvcValue);
            var reg = new RegExp("([0-9]{" + this._cvvMaskLength + "})", 'g');
            var cvcmask = cvcValueFormatted === null || cvcValueFormatted === void 0 ? void 0 : cvcValueFormatted.replace(reg, '$1');
            this._rendererTimeout = window === null || window === void 0 ? void 0 : window.setTimeout(function () {
                _this._ngControl.viewToModelUpdate(cvcmask);
                _this._ngControl.valueAccessor.writeValue(cvcmask);
            }, TIMEOUT_SECONDS);
        };
        /**
         * Registers a callback function that is called when the control's value changes in the UI.
         * @param onChange - {fn}
         */
        CardCvvDirective.prototype.registerOnChange = function (onChange) {
            this.onChange = onChange;
        };
        /**
         * Registers a callback function that is called by the forms API on initialization to update the form model on blur.
         * @param onTouched - {fn}
         */
        CardCvvDirective.prototype.registerOnTouched = function (onTouched) {
            this.onTouched = onTouched;
        };
        /**
         * set element ref as disabled
         * @param isDisabled - set element as disabled
         */
        CardCvvDirective.prototype.setDisabledState = function (isDisabled) {
            this._renderer.setProperty(this._el, 'disabled', isDisabled);
            this._control.disable({ onlySelf: true });
            this._ngControl.valueAccessor.setDisabledState(isDisabled);
        };
        /**
         * Set the mask size based on card type (from card BIN)
         */
        CardCvvDirective.prototype._setCardCvcMask = function () {
            var _this = this;
            this._cardTypeService.cardType
                .pipe(operators.takeUntil(this._destroy$), operators.map(function (type) {
                var _a;
                _this._cvvMaskLength = (_a = type === null || type === void 0 ? void 0 : type.code) === null || _a === void 0 ? void 0 : _a.length;
                return type;
            }))
                .subscribe();
        };
        /**
         * setup input with some attrs for better user experience
         */
        CardCvvDirective.prototype._setupInput = function () {
            this._renderer.setProperty(this._el, 'autoComplete', 'cc-csc');
            this._renderer.setProperty(this._el, 'aria-label', 'Card CVC');
            this._renderer.setProperty(this._el, 'id', 'cccvc');
            this._renderer.setProperty(this._el, 'name', 'cccvc');
            this._renderer.setProperty(this._el, 'type', 'tel');
        };
        return CardCvvDirective;
    }());
    CardCvvDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: 'input[formControlName][jstCardCvv],input[formControl][jstCardCvv]',
                    host: {
                        '(blur)': 'onTouched()',
                    },
                },] }
    ];
    CardCvvDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef },
        { type: forms.NgControl, decorators: [{ type: core.Optional }] },
        { type: CardTypeService }
    ]; };
    CardCvvDirective.propDecorators = {
        onCardChanges: [{ type: core.HostListener, args: ['input', ['$event'],] }],
        onCardBlur: [{ type: core.HostListener, args: ['blur', ['$event'],] }],
        onKeyDown: [{ type: core.HostListener, args: ['keydown', ['$event'],] }]
    };

    var PaymentInputsModule = /** @class */ (function () {
        function PaymentInputsModule() {
        }
        return PaymentInputsModule;
    }());
    PaymentInputsModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    declarations: [CardNumberDirective, CardExpireDateDirective, CardCvvDirective],
                    exports: [CardNumberDirective, CardExpireDateDirective, CardCvvDirective],
                    providers: [CardTypeService],
                },] }
    ];

    /**
     * @dynamic
     * Class with validators to use with Payment Input directives and reactive forms.
     * All class methods are static.
     *
     * @example
     * Example with a form group:
     * ```ts
     *   ngOnInit(): void {
     *    this.form = this.fb.group({
     *      cardNumber: [null, [PaymentInputValidators.validateCardNumber()]],
     *      cardCvc: [null, [PaymentInputValidators.validateCardExpiryDate()]],
     *      cardValidate: [null, [PaymentInputValidators.validateCVC()]],
     *    });
     *  }
     * ```
     */
    var PaymentInputValidators = /** @class */ (function () {
        function PaymentInputValidators() {
        }
        /**
         * Validate a card number
         * @returns Angular validator function
         * @static
         */
        PaymentInputValidators.cardNumber = function () {
            return function (control) {
                var value = control === null || control === void 0 ? void 0 : control.value;
                var cardNumberError = utils.validators.getCardNumberError(value, null);
                return !cardNumberError ? null : { 'card-number': cardNumberError };
            };
        };
        /**
         * Validate a card expiry date
         * @returns Angular validator function
         * @static
         */
        PaymentInputValidators.expiryDate = function () {
            return function (control) {
                var value = control === null || control === void 0 ? void 0 : control.value;
                var cardNumberError = utils.validators.getExpiryDateError(value, null);
                return !cardNumberError ? null : { 'card-expiry': cardNumberError };
            };
        };
        /**
         * Validate a card CVC
         * @returns Angular validator function
         * @static
         */
        PaymentInputValidators.CVC = function () {
            return function (control) {
                var value = control === null || control === void 0 ? void 0 : control.value;
                var cardNumberError = utils.validators.getCVCError(value, null);
                return !cardNumberError ? null : { 'card-cvc': cardNumberError };
            };
        };
        return PaymentInputValidators;
    }());

    /**
     * Generated bundle index. Do not edit.
     */

    exports.CardCvvDirective = CardCvvDirective;
    exports.CardExpireDateDirective = CardExpireDateDirective;
    exports.CardNumberDirective = CardNumberDirective;
    exports.CardTypeService = CardTypeService;
    exports.PaymentInputValidators = PaymentInputValidators;
    exports.PaymentInputsModule = PaymentInputsModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-payment-inputs.umd.js.map
