import * as cardTypes from './card-types';
/**
 * @description format card number based on card type list per card BIN
 * @param cardNumber {string} - card number form html input
 */
export const formatCardNumber = (cardNumber) => {
    var _a, _b;
    const cardType = cardTypes.getCardTypeByValue(cardNumber);
    if (!cardType)
        return (_a = ((cardNumber === null || cardNumber === void 0 ? void 0 : cardNumber.match(/\d+/g)) || [])) === null || _a === void 0 ? void 0 : _a.join('');
    const format = cardType === null || cardType === void 0 ? void 0 : cardType.format;
    if (format === null || format === void 0 ? void 0 : format.global) {
        return (_b = ((cardNumber === null || cardNumber === void 0 ? void 0 : cardNumber.match(format)) || [])) === null || _b === void 0 ? void 0 : _b.join(' ');
    }
    if (format) {
        const execResult = format.exec(cardNumber.split(' ').join(''));
        if (execResult) {
            return execResult
                .splice(1, 3)
                .filter((x) => x)
                .join(' ');
        }
    }
    return cardNumber;
};
/**
 * @description Format expiry date based on card BIN
 * @param event {unknown} - Event from card date expiry date
 * @returns string
 */
export const formatExpiry = (event) => {
    var _a, _b, _c, _d;
    const eventData = (_a = event === null || event === void 0 ? void 0 : event.nativeEvent) === null || _a === void 0 ? void 0 : _a.data;
    const prevExpiry = (_d = (_c = (_b = event === null || event === void 0 ? void 0 : event.target) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.split(' / ')) === null || _d === void 0 ? void 0 : _d.join('/');
    if (!prevExpiry)
        return null;
    let expiry = prevExpiry;
    if (/^[2-9]$/.test(expiry)) {
        expiry = `0${expiry}`;
    }
    if (prevExpiry.length === 2 && +prevExpiry > 12) {
        const [head, ...tail] = prevExpiry.split('');
        expiry = `0${head}/${tail.join('')}`;
    }
    if (/^1[/-]$/.test(expiry)) {
        return `01 / `;
    }
    expiry = expiry.match(/(\d{1,2})/g) || [];
    if ((expiry === null || expiry === void 0 ? void 0 : expiry.length) === 1) {
        if (!eventData && prevExpiry.includes('/')) {
            return expiry[0];
        }
        if (/\d{2}/.test(expiry)) {
            return `${expiry[0]} / `;
        }
    }
    if ((expiry === null || expiry === void 0 ? void 0 : expiry.length) > 2) {
        const [, month = null, year = null] = expiry.join('').match(/^(\d{2}).*(\d{2})$/) || [];
        return [month, year].join(' / ');
    }
    return expiry.join(' / ');
};
//# sourceMappingURL=formatters.js.map