import utils from '../utils';
/**
 * @dynamic
 * Class with validators to use with Payment Input directives and reactive forms.
 * All class methods are static.
 *
 * @example
 * Example with a form group:
 * ```ts
 *   ngOnInit(): void {
 *    this.form = this.fb.group({
 *      cardNumber: [null, [PaymentInputValidators.validateCardNumber()]],
 *      cardCvc: [null, [PaymentInputValidators.validateCardExpiryDate()]],
 *      cardValidate: [null, [PaymentInputValidators.validateCVC()]],
 *    });
 *  }
 * ```
 */
export class PaymentInputValidators {
    /**
     * Validate a card number
     * @returns Angular validator function
     * @static
     */
    static cardNumber() {
        return (control) => {
            const value = control === null || control === void 0 ? void 0 : control.value;
            const cardNumberError = utils.validators.getCardNumberError(value, null);
            return !cardNumberError ? null : { 'card-number': cardNumberError };
        };
    }
    /**
     * Validate a card expiry date
     * @returns Angular validator function
     * @static
     */
    static expiryDate() {
        return (control) => {
            const value = control === null || control === void 0 ? void 0 : control.value;
            const cardNumberError = utils.validators.getExpiryDateError(value, null);
            return !cardNumberError ? null : { 'card-expiry': cardNumberError };
        };
    }
    /**
     * Validate a card CVC
     * @returns Angular validator function
     * @static
     */
    static CVC() {
        return (control) => {
            const value = control === null || control === void 0 ? void 0 : control.value;
            const cardNumberError = utils.validators.getCVCError(value, null);
            return !cardNumberError ? null : { 'card-cvc': cardNumberError };
        };
    }
}
//# sourceMappingURL=index.js.map