import { ValidatorFn } from '@angular/forms';
/**
 * @dynamic
 * Class with validators to use with Payment Input directives and reactive forms.
 * All class methods are static.
 *
 * @example
 * Example with a form group:
 * ```ts
 *   ngOnInit(): void {
 *    this.form = this.fb.group({
 *      cardNumber: [null, [PaymentInputValidators.validateCardNumber()]],
 *      cardCvc: [null, [PaymentInputValidators.validateCardExpiryDate()]],
 *      cardValidate: [null, [PaymentInputValidators.validateCVC()]],
 *    });
 *  }
 * ```
 */
export declare class PaymentInputValidators {
    /**
     * Validate a card number
     * @returns Angular validator function
     * @static
     */
    static cardNumber(): ValidatorFn;
    /**
     * Validate a card expiry date
     * @returns Angular validator function
     * @static
     */
    static expiryDate(): ValidatorFn;
    /**
     * Validate a card CVC
     * @returns Angular validator function
     * @static
     */
    static CVC(): ValidatorFn;
}
